===========
Release 2.1
===========

Bug Fixes
---------
* Fix bug with ``server start`` when only frontend LDAP in Presto is enabled.
* Fix intermittent bug with ``server start`` printing out irrelevant error messages.
